@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: mnemo/lib/prefs.php,v 1.2.10.4 2006/01/01 21:29:06 jan Exp $
+ * $Horde: mnemo/lib/prefs.php,v 1.2.10.5 2006/07/17 10:33:08 jan Exp $
  *
  * Copyright 2002-2006 Chuck Hagenbuch <chuck@horde.org>
  *
@@ -26,12 +26,3 @@ function handle_notepadselect($updated)
     }
     return $updated;
 }
-
-function handle_showsummaryselect($updated)
-{
-    global $prefs;
-
-    $summary_categories = Util::getFormData('summary_categories');
-    $prefs->setValue('summary_categories', $summary_categories);
-    return true;
-}
